@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.27.1";
+our $VERSION = "v0.28.0";
 
 1;
 __END__
@@ -26,81 +26,40 @@ RxPerl - an implementation of Reactive Extensions / rxjs for Perl
 
 =head1 SYNOPSIS
 
-=pod
+    # one of...:
 
-    use RxPerl::AnyEvent ':all';
-    use AnyEvent;
+    > cpanm RxPerl::AnyEvent
+    > cpanm RxPerl::IOAsync
+    > cpanm RxPerl::Mojo
 
-    sub make_observer ($i) {
-        return {
-            next     => sub {say "next #$i: ", $_[0]},
-            error    => sub {say "error #$i: ", $_[0]},
-            complete => sub {say "complete #$i"},
-        };
-    }
 
-    my $o = rx_interval(0.7)->pipe(
-        op_map(sub {$_[0] * 2}),
-        op_take_until( rx_timer(5) ),
-    );
+    # ..and then (if installed RxPerl::Mojo, for example):
 
-    $o->subscribe(make_observer(1));
-
-    AnyEvent->condvar->recv;
-
-=pod
-
-    use RxPerl::IOAsync ':all';
-    use IO::Async::Loop;
-
-    my $loop = IO::Async::Loop->new;
-    RxPerl::IOAsync::set_loop($loop);
-
-    sub make_observer ($i) {
-        return {
-            next     => sub {say "next #$i: ", $_[0]},
-            error    => sub {say "error #$i: ", $_[0]},
-            complete => sub {say "complete #$i"},
-        };
-    }
-
-    my $o = rx_interval(0.7)->pipe(
-        op_map(sub {$_[0] * 2}),
-        op_take_until( rx_timer(5) ),
-    );
-
-    $o->subscribe(make_observer(1));
-
-    $loop->run;
-
-=pod
-
-    use RxPerl::Mojo ':all';
+    use RxPerl::Mojo 'rx_interval', 'op_take';
     use Mojo::IOLoop;
 
-    sub make_observer ($i) {
-        return {
-            next     => sub {say "next #$i: ", $_[0]},
-            error    => sub {say "error #$i: ", $_[0]},
-            complete => sub {say "complete #$i"},
-        };
-    }
-
-    my $o = rx_interval(0.7)->pipe(
-        op_map(sub {$_[0] * 2}),
-        op_take_until( rx_timer(5) ),
-    );
-
-    $o->subscribe(make_observer(1));
+    rx_interval(1.4)->pipe(
+        op_take(5),
+    )->subscribe(sub { say "next: ", $_[0] });
 
     Mojo::IOLoop->start;
 
+=head1 NOTE
+
+You probably want to install one of the three adapter modules for your project instead of this one:
+L<RxPerl::AnyEvent>, L<RxPerl::IOAsync> or L<RxPerl::Mojo>.
+
+Each of these three modules adapt RxPerl to one of three event loops available in Perl (L<AnyEvent>,
+L<IO::Async> and L<Mojo::IOLoop>), so pick the one that corresponds to the event loop that your app uses.
+
+The documentation in this POD applies to all three adapter modules.
+
 =head1 DESCRIPTION
 
 This module is an implementation of L<Reactive Extensions|http://reactivex.io/> in Perl. It replicates the
 behavior of L<rxjs 6|https://www.npmjs.com/package/rxjs> which is the JavaScript implementation of ReactiveX.
 
-Currently 44 of the 100+ operators in rxjs are implemented in this module.
+Currently 47 of the 100+ operators in rxjs are implemented in this module.
 
 =head1 EXPORTABLE FUNCTIONS
 
@@ -787,21 +746,11 @@ ReactiveX to cater for web developers already familiar with rxjs.
 
 =back
 
-=head1 TODO
-
-=over
-
-=item * Fix the occasional bug
-
-=item * Implement more operators, based on user requests
-
-=back
-
 =head1 SEE ALSO
 
 =over
 
-=item * L<Ryu|https://metacpan.org/pod/Ryu>
+=item * L<Ryu>
 
 =back
 
@@ -818,6 +767,6 @@ it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-KARJALA Corp E<lt>karjala@cpan.orgE<gt>
+KARJALA E<lt>karjala@cpan.orgE<gt>
 
 =cut
